# Verse ML

A framework for producing production quality ML tools

## Immediate Roadmap

- Build initial API for running training jobs on remote GPUs transparently from the command line.
- Build initial API for introspecting these jobs while they're running.
- Build initial API for deploying those models to lambdas/other serverless execution environments.
